#  Yagan "The Growth Dividend and Excess Interest" (2024) 

By Danny Yagan 

-------

## Data Inputs
- The paper uses data from the Congressional Budget Office (CBO) and the Office of Management and Budget (OMB).
- CBO: 
  - CBO's Historical Budget Data: Feb 2024, link [here](https://www.cbo.gov/system/files/2024-02/51134-2024-02-Historical-Budget-Data.xlsx)
  - CBO's 10-Year Budget Projections: Jun 2024, link [here](https://www.cbo.gov/system/files/2024-06/51118-2024-06-Budget-Projections.xlsx)
  - CBO's Long-Term Budget Projections: Jun 2024, link [here](https://www.cbo.gov/system/files/2024-03/51119-2024-03-LTBO-budget.xlsx)
  - All values are converted to billions of current-year dollars and appended into the master input file `excess_interest_inputs_20240715.csv`
- OMB:
  - Budget of the US government: fiscal year 2024, link [here](https://www.govinfo.gov/content/pkg/BUDGET-2024-BUD.zip)
## Script

- `excessinterest_v3_240715.do`: This Stata script uses historical and projected data from the Congressional Budget Office (CBO) to generate all figures in the paper. The remaining exhibits are created in the excel files in `/do/`. 

- **Data Sources:** Inputs data from `excess_interest_inputs_20240715.csv` containing historical and projected debt, interest, and GDP figures.
- **Intermediate Output:** `excess_interest_analysis_data.dta`: Processed data saved in Stata format for further analysis.

- **Key Calculations:**
  - `debtchange`: Yearly changes in debt.
  - `deficit` and `primarydeficit`: Derived from outlays, revenues, and interest.
  - `growthdividend`: Product of GDP growth and prior-year debt.
  - `excessinterest`: Difference between interest and the growth dividend.
  - Metrics normalized as a percentage of GDP.
- **Key Outputs:**
    - **Figures:**
      - `deficitvsdebtratiochange_20032007_20242034_full.pdf` (Figure 1)
      - `cbo10yr_combinedeficit.pdf` (Figure 2A)
      - `cbo10yr_excessinterest.pdf` (Figure 2B)
      - `ivsg_2024to2054.pdf` (Figure 3)

    - **Summaries:**
        - `decomposition_1962_2034.csv`: used to create `table2_decompbyyear.pdf` (Table 2) and `table3_excessinterestbyyear.pdf` (Table 3) by exporting from excel to pdf 


  ## Excel workbooks

- `CBO ten year tables v4.xlsx`: uses inputs from CBO data sheets to create sheet `Table 1 - paper`, which is then exported to `table1_CBO_paper.pdf` (Table 1).
- `PB24 Summary Tables dy v2.xlsx`: uses inputs from OMB data sheets to create sheet `S-1 dy`, which is then exported to `table4_OMB_paper.pdf` (Table 4). 
