******************************************
* EXCESS INTEREST ANALYSIS
******************************************
global dropbox = "/Users/tcejka/Documents/repo"
global root = "$dropbox/debt/dy"
global do = "$root/do"
global out = "$root/out"
global dump = "$root/dump"
global raw = "$root/raw"
global dta = "$root/dta"
cd $dump

set more off
global gpr = "plotregion(fcolor(white) lcolor(white) m(tiny)) graphregion(fcolor(white) lcolor(white))"
global end = "pdf"


*INSHEET
insheet using $raw/excess_interest_inputs_20240715.csv, comma clear

*CREATE VALUES AND SAVE, CAREFULLY HANDLING THE FACT THAT WE HAVE 
* 2024-2034 DATA FROM BOTH THE LTBO AND THE 10-YEAR OUTLOOK
gen zzcbo10yr = source=="cbo10yr"
**CODE HISTORICAL DATA AND LTBO DATA
sort zzcbo10yr year
gen debtchange = debt-debt[_n-1]
gen deficit = outlays - revenues
gen primarydeficit = deficit - interest
gen miscellaneous = debtchange - primarydeficit - interest
gen g = gdp/gdp[_n-1] - 1
gen growthdividend = g*debt[_n-1]
gen excessinterest = interest - growthdividend
foreach term in debt interest deficit primarydeficit growthdividend excessinterest miscellaneous {
	gen `term'_gdp = 100*`term'/gdp
}
gen debtratiochange = debt_gdp - debt_gdp[_n-1]
gen r = interest/(debt[_n-1] + .5*primarydeficit)
**CODE 10YR DATA
replace zzcbo10yr=1 if source=="cbohistorical"
gsort -zzcbo10yr year 
replace debtchange = debt-debt[_n-1] if source=="cbo10yr"
replace deficit = outlays - revenues if source=="cbo10yr"
replace primarydeficit = deficit - interest if source=="cbo10yr"
replace miscellaneous = debtchange - primarydeficit - interest if source=="cbo10yr"
replace g = gdp/gdp[_n-1] - 1 if source=="cbo10yr"
replace growthdividend = -g*debt[_n-1] if source=="cbo10yr"
replace excessinterest = interest + growthdividend if source=="cbo10yr"
foreach term in debt interest deficit primarydeficit growthdividend excessinterest miscellaneous {
	replace `term'_gdp = 100*`term'/gdp if source=="cbo10yr"
}
replace debtratiochange = debt_gdp - debt_gdp[_n-1] if source=="cbo10yr"
replace r = interest/(debt[_n-1] + .5*primarydeficit) if source=="cbo10yr"

**SAVE
replace zzcbo10yr = source=="cbo10yr"
sort zzcbo10yr year
drop zz*
save ${dta}/excess_interest_analysis_data, replace

*MAKE INTRO BAR GRAPHS
**PERIOD AVERAGES VERSION
use ${dta}/excess_interest_analysis_data, clear
keep if inrange(year,2003,2007) | source=="cbo10yr"
drop if year==2024
collapse (mean) deficit_gdp debtratiochange, by(source)
*** TO MATCH THE CBO'S TABLE WHICH USES MORE SIG FIGS
replace deficit_gdp=deficit_gdp+.1 if source=="cbo10yr"
gen str10 group = ""
replace group = "2003-2007" if source == "cbohistorical"
replace group = "2024-2034 (projected)" if source == "cbo10yr"
**FULL VERSION
graph bar (mean) deficit_gdp debtratiochange, over(group, gap(30)) ///
    bar(1, color(navy) lcolor(black) lwidth(medthick)) ///
    bar(2, color(white) lcolor(black) lwidth(medthick)) ///
    ylabel(, angle(horizontal)) ///
    ytitle("Percent of GDP") ///
    legend(order(1 "Deficit" 2 "Debt ratio change") position(bottom) rows(1)) ///
    blabel(bar, format(%9.1f) size(small)) ///
    nofill ///
    asyvars ///
    title("") ///
    note("") ///
    b1title("") ylab(,nogrid)
graph export "$out/deficitvsdebtratiochange_20032007_20242034_full.$end", replace

*10YR OUTLOOK GRAPH
use ${dta}/excess_interest_analysis_data if source=="cbo10yr", clear
**COMBINE THE DEFICIT
twoway (scatter debtratiochange year, c(l) lc(navy) lp(solid) lwidth(medthick) m(i)) ///
	|| (scatter deficit_gdp year, c(l) lc(purple) lp(dash) lwidth(medthick) m(i) msize(medsmall)) ///
	|| (scatter growthdividend_gdp year, c(l) lc(orange) lp(shortdash_dot) lwidth(medthick) m(i)) ///
	|| (scatter miscellaneous_gdp year, c(l) lc(black) lp(dot) lwidth(medthick) m(i)), ///
	$gpr /// 
	title("") ///
	ytitle("Percent of GDP") ///
	xtitle("") ///
	ysc(titlegap(2)) xsc(titlegap(1)) ///
	legend(label(1 "Debt ratio change") ///
	label(2 "Deficit") ///
	label(3 "Growth dividend") ///
	label(4 "Other means of financing") ///
	row(2) region(lc(white)) position(bottom)) ///
	xlab(2024(1)2034, nogrid) ///
	yline(0, lc(black) lp(solid) lwidth(thin)) ///
	ylabel(-5(2.5)7.5, grid glpattern(solid) glwidth(vthin) glcolor(gs15))
graph export "$out/cbo10yr_combinedeficit.$end", replace
**COMBINE EXCESS INTEREST
twoway (scatter debtratiochange year, c(l) lc(navy) lp(solid) lwidth(medthick) m(i)) ///
	|| (scatter primarydeficit_gdp year, c(l) lc(cranberry) lp(dash) lwidth(medthick) m(i) msize(medsmall)) ///
	|| (scatter excessinterest_gdp year, c(l) lc(green) lp(shortdash_dot) lwidth(medthick) m(i)) ///
	|| (scatter miscellaneous_gdp year, c(l) lc(black) lp(dot) lwidth(medthick) m(i)), ///
	$gpr /// 
	title("") ///
	ytitle("Percent of GDP") ///
	xtitle("") ///
	ysc(titlegap(2)) xsc(titlegap(1)) ///
	legend(label(1 "Debt ratio change") ///
	label(2 "Primary deficit") ///
	label(3 "Excess interest") ///
	label(4 "Other means of financing") ///
	row(2) region(lc(white)) position(bottom)) ///
	xlab(2024(1)2034, nogrid) ///
	yline(0, lc(black) lp(solid) lwidth(thin)) ///
	ylabel(-5(2.5)7.5, grid glpattern(solid) glwidth(vthin) glcolor(gs15))
graph export "$out/cbo10yr_excessinterest.$end", replace

*r VS g GRAPH
use ${dta}/excess_interest_analysis_data if source=="cboltbo", clear
foreach var in r g {
	gen `var'x100 = `var'*100
}
twoway (scatter gx100 year, c(l) lp(solid) lwidth(medthick) m(i)) ///
	|| (scatter rx100 year, c(l) lp(dash) lwidth(medthick) m(i) msize(medsmall)), ///
	$gpr /// 
	title("") ///
	ytitle("Percent") ///
	xtitle("") ///
	ysc(titlegap(2)) xsc(titlegap(1)) ///
	legend(label(1 "Nominal GDP growth rate") ///
	label(2 "Nominal interest rate") ///
	row(2) region(lc(white)) position(bottom)) ///
	xlab(2024(5)2054, nogrid) ///
	ylab(,grid glpattern(solid) glwidth(vthin) glcolor(gs15)) 
graph export "$out/rvsg_2024to2054.$end", replace

*OUTSHEET FOR TABLE DISPLAYING RAW DECOMPOSITION 1962-2034
use ${dta}/excess_interest_analysis_data, clear
keep if source=="cbo10yr" | inrange(year,1962,2023)
order year debt_gdp debtratiochange primarydeficit_gdp interest_gdp growthdividend_gdp miscellaneous_gdp
outsheet using ${dta}/decomposition_1962_2034.csv, comma replace

*STATISTICS ON r OVER TIME FOR THE INTRODUCTION
use ${dta}/excess_interest_analysis_data, clear
sum primarydeficit_gdp debt_gdp interest_gdp r growthdividend_gdp excessinterest_gdp if inrange(year,2003,2007)
sum primarydeficit_gdp debt_gdp interest_gdp r growthdividend_gdp excessinterest_gdp if source=="cbo10yr"


